==> ejc-settle-impl-3.0.0-20240618.002543-48-sources.jar: com/ejianc/business/settle/service/impl/SettlementCenterBudgetOtherServiceImpl.java <==
package com.ejianc.business.settle.service.impl;

import com.alibaba.fastjson.JSONObject;
import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.core.toolkit.IdWorker;
import com.ejianc.business.settle.bean.*;
import com.ejianc.business.settle.service.ISettlementCenterDcDrwgrpInfoService;
import com.ejianc.framework.core.kit.mapper.BeanMapper;
import com.ejianc.framework.core.response.CommonResponse;
import com.ejianc.framework.core.util.ExcelReader;
import com.ejianc.framework.core.util.FileUtils;
import org.apache.commons.lang3.StringUtils;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import com.ejianc.framework.skeleton.template.BaseServiceImpl;

import com.ejianc.business.settle.mapper.SettlementCenterBudgetOtherMapper;
import com.ejianc.business.settle.bean.SettlementCenterBudgetOtherEntity;
import com.ejianc.business.settle.service.ISettlementCenterBudgetOtherService;
import org.springframework.web.multipart.MultipartFile;
import org.springframework.web.multipart.MultipartHttpServletRequest;

import javax.servlet.http.HttpServletRequest;
import java.math.BigDecimal;
import java.util.ArrayList;
import java.util.Comparator;
import java.util.List;
import java.util.Map;
import java.util.stream.Collectors;

/**
 * 建筑工程
 *
 * @author generator
 */
@Service("settlementCenterBudgetOtherService")
public class SettlementCenterBudgetOtherServiceImpl extends BaseServiceImpl<SettlementCenterBudgetOtherMapper, SettlementCenterBudgetOtherEntity> implements ISettlementCenterBudgetOtherService {
    @Autowired
    private ISettlementCenterDcDrwgrpInfoService dcDrwgrpInfoService;

    private Logger logger = LoggerFactory.getLogger(this.getClass());

    @Override
    public CommonResponse<JSONObject> excelImport(Long settlementCenterDcDrwgrpInfoId, HttpServletRequest request) {
        MultipartHttpServletRequest multipartRequest = (MultipartHttpServletRequest) request;
        Map<String, MultipartFile> fileMap = multipartRequest.getFileMap();

        MultipartFile mf = null;

        List<SettlementCenterBudgetOtherVO> successList = new ArrayList<>();
        List<SettlementCenterBudgetOtherVO> errorList = new ArrayList<>();
        List<SettlementCenterBudgetOtherVO> rtErrorList = new ArrayList<>();

        boolean isFailed = false;
        for (Map.Entry<String, MultipartFile> entry : fileMap.entrySet()) {
            mf = entry.getValue();
            String originalFileName = mf.getOriginalFilename();
            String extName = null;
            originalFileName = originalFileName.replaceAll("\\/|\\/|\\||:|\\?|\\*|\"|<|>|\\p{Cntrl}", "_");
            originalFileName.replaceAll("00.", "");
            extName = FileUtils.getFileExt(originalFileName, false);
            if (!"xls".equals(extName) && !"xlsx".equals(extName)) {
                isFailed = true;
                break;
            }
        }

        if (isFailed) {
            return CommonResponse.error("文件格式不合法");
        } else {

            List<List<String>> result = ExcelReader.readExcel(mf);
            if (result != null && result.size() > 0) {
                if (result.size() > 10000) {
                    return CommonResponse.error("信息超过10000条，请分批上传！");
                }
            }

            SettlementCenterDcDrwgrpInfoEntity drwgrpInfoEntity = dcDrwgrpInfoService.selectById(settlementCenterDcDrwgrpInfoId);
            for (int i = 1; i < result.size(); i++) {
                StringBuilder errmessage = new StringBuilder("");
                boolean flag = true;
                List<String> data = result.get(i);
                String index = data.get(0);
                String code = data.get(1);
                String name = data.get(2);
                String otherNum = data.get(7);//统计工程量
                String settlementCenterOtherMny = data.get(8);//统计产值(无税)
                String settlementCenterOtherTaxMny = data.get(9);//统计产值(含税)
                String settlementCenterOtherTax = data.get(10);//统计产值税额
                if (StringUtils.isNotEmpty(otherNum)) {
                    SettlementCenterBudgetOtherEntity one = this.getOne(
                            new QueryWrapper<SettlementCenterBudgetOtherEntity>().lambda()
                                    .eq(SettlementCenterBudgetOtherEntity::getBudgetId, drwgrpInfoEntity.getBudgeId())
                                    .eq(SettlementCenterBudgetOtherEntity::getDetailIndex, index)
                                    .eq(SettlementCenterBudgetOtherEntity::getOtherCode, code)
                                    .eq(SettlementCenterBudgetOtherEntity::getOtherName, name)
                                    .eq(SettlementCenterBudgetOtherEntity::getDcDrwgrpInfo,0)
                    );
                    if (one != null) {
                        one.setParentId(one.getId());
                        one.setId(IdWorker.getId());
                        if (StringUtils.isEmpty(otherNum)){
                            flag = false;
                            errmessage.append("[统计工程量]为空;");
                        }
                        if (StringUtils.isEmpty(settlementCenterOtherMny)){
                            flag = false;
                            errmessage.append("[统计产值(无税)]为空;");
                        }
                        if (StringUtils.isEmpty(settlementCenterOtherTaxMny)){
                            flag = false;
                            errmessage.append("[统计产值(含税)]为空;");
                        }
                        if (StringUtils.isEmpty(settlementCenterOtherTax)){
                            flag = false;
                            errmessage.append("[统计产值税额]为空;");
                        }
                        if (flag = false){
                            SettlementCenterBudgetOtherVO vo = BeanMapper.map(one, SettlementCenterBudgetOtherVO.class);
                            vo.setErrorMessage(errmessage.toString());
                            vo.setRowIndex(i);
                            errorList.add(vo);
                            continue;
                        }

                        one.setSettlementCenterOtherNum(new BigDecimal(otherNum));
                        one.setSettlementCenterOtherTaxMny(new BigDecimal(settlementCenterOtherTaxMny));
                        one.setSettlementCenterOtherMny(new BigDecimal(settlementCenterOtherMny));
                        one.setSettlementCenterOtherTax(new BigDecimal(settlementCenterOtherTax));
                        one.setDcDrwgrpInfo(drwgrpInfoEntity.getId());
                        SettlementCenterBudgetOtherVO vo = BeanMapper.map(one, SettlementCenterBudgetOtherVO.class);
                        successList.add(vo);
                    } else {
                        SettlementCenterBudgetOtherVO vo = new SettlementCenterBudgetOtherVO();
                        logger.info("第" + i + "行数据:" + StringUtils.join(data, ","));
                        vo.setRowIndex(i);
                        vo.setErrorMessage("明细未找到");
                        errorList.add(vo);
                    }

                }
            }


        }
        JSONObject json = new JSONObject();
        json.put("successList", successList);
        rtErrorList = errorList.stream().sorted(Comparator.comparing(SettlementCenterBudgetOtherVO::getRowIndex)).collect(Collectors.toList());
        json.put("errorList", rtErrorList);
        CommonResponse<JSONObject> success = CommonResponse.success(json);
        return success;
    }
}

==> ejc-settle-impl-3.0.0-20250725.032806-167-sources.jar: com/ejianc/business/settle/service/impl/SettlementCenterBudgetOtherServiceImpl.java <==
package com.ejianc.business.settle.service.impl;

import com.alibaba.fastjson.JSONObject;
import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.core.toolkit.IdWorker;
import com.ejianc.business.settle.bean.*;
import com.ejianc.business.settle.service.ISettlementCenterDcDrwgrpInfoService;
import com.ejianc.framework.core.kit.mapper.BeanMapper;
import com.ejianc.framework.core.response.CommonResponse;
import com.ejianc.framework.core.util.ExcelReader;
import com.ejianc.framework.core.util.FileUtils;
import org.apache.commons.lang3.StringUtils;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import com.ejianc.framework.skeleton.template.BaseServiceImpl;

import com.ejianc.business.settle.mapper.SettlementCenterBudgetOtherMapper;
import com.ejianc.business.settle.bean.SettlementCenterBudgetOtherEntity;
import com.ejianc.business.settle.service.ISettlementCenterBudgetOtherService;
import org.springframework.web.multipart.MultipartFile;
import org.springframework.web.multipart.MultipartHttpServletRequest;

import javax.servlet.http.HttpServletRequest;
import java.math.BigDecimal;
import java.math.RoundingMode;
import java.util.ArrayList;
import java.util.Comparator;
import java.util.List;
import java.util.Map;
import java.util.stream.Collectors;

/**
 * 建筑工程
 *
 * @author generator
 */
@Service("settlementCenterBudgetOtherService")
public class SettlementCenterBudgetOtherServiceImpl extends BaseServiceImpl<SettlementCenterBudgetOtherMapper, SettlementCenterBudgetOtherEntity> implements ISettlementCenterBudgetOtherService {
    @Autowired
    private ISettlementCenterDcDrwgrpInfoService dcDrwgrpInfoService;

    private Logger logger = LoggerFactory.getLogger(this.getClass());

    @Override
    public CommonResponse<JSONObject> excelImport(Long settlementCenterDcDrwgrpInfoId, HttpServletRequest request) {
        MultipartHttpServletRequest multipartRequest = (MultipartHttpServletRequest) request;
        Map<String, MultipartFile> fileMap = multipartRequest.getFileMap();

        MultipartFile mf = null;

        List<SettlementCenterBudgetOtherVO> successList = new ArrayList<>();
        List<SettlementCenterBudgetOtherVO> errorList = new ArrayList<>();
        List<SettlementCenterBudgetOtherVO> rtErrorList = new ArrayList<>();

        boolean isFailed = false;
        for (Map.Entry<String, MultipartFile> entry : fileMap.entrySet()) {
            mf = entry.getValue();
            String originalFileName = mf.getOriginalFilename();
            String extName = null;
            originalFileName = originalFileName.replaceAll("\\/|\\/|\\||:|\\?|\\*|\"|<|>|\\p{Cntrl}", "_");
            originalFileName.replaceAll("00.", "");
            extName = FileUtils.getFileExt(originalFileName, false);
            if (!"xls".equals(extName) && !"xlsx".equals(extName)) {
                isFailed = true;
                break;
            }
        }

        if (isFailed) {
            return CommonResponse.error("文件格式不合法");
        } else {

            List<List<String>> result = ExcelReader.readExcel(mf);
            if (result != null && result.size() > 0) {
                if (result.size() > 10000) {
                    return CommonResponse.error("信息超过10000条，请分批上传！");
                }
            }

            SettlementCenterDcDrwgrpInfoEntity drwgrpInfoEntity = dcDrwgrpInfoService.selectById(settlementCenterDcDrwgrpInfoId);
            for (int i = 1; i < result.size(); i++) {
                StringBuilder errmessage = new StringBuilder("");
                boolean flag = true;
                List<String> data = result.get(i);
                String index = data.get(0);
                String code = data.get(1);
                String name = data.get(2);
                String otherNum = data.get(5);//统计工程量
                String memo = data.get(6);//备注
                if (StringUtils.isNotEmpty(otherNum)) {
                    SettlementCenterBudgetOtherEntity one = this.getOne(
                            new QueryWrapper<SettlementCenterBudgetOtherEntity>().lambda()
                                    .eq(SettlementCenterBudgetOtherEntity::getBudgetId, drwgrpInfoEntity.getBudgeId())
                                    .eq(SettlementCenterBudgetOtherEntity::getDetailIndex, index)
                                    .eq(SettlementCenterBudgetOtherEntity::getOtherCode, code)
                                    .eq(SettlementCenterBudgetOtherEntity::getOtherName, name)
                                    .eq(SettlementCenterBudgetOtherEntity::getDcDrwgrpInfo,0)
                    );
                    if (one != null) {
                        one.setParentId(one.getId());
                        one.setId(IdWorker.getId());
                        if (StringUtils.isEmpty(otherNum)){
                            flag = false;
                            errmessage.append("[统计工程量]为空;");
                        }
                        
                        if (flag = false){
                            SettlementCenterBudgetOtherVO vo = BeanMapper.map(one, SettlementCenterBudgetOtherVO.class);
                            vo.setErrorMessage(errmessage.toString());
                            vo.setRowIndex(i);
                            errorList.add(vo);
                            continue;
                        }

                        one.setSettlementCenterOtherNum(new BigDecimal(otherNum));
                        if (one.getOtherTaxPrice() != null && !one.getOtherTaxPrice().equals(BigDecimal.ZERO)) {
                            //统计产值(含税)
                            one.setSettlementCenterOtherTaxMny(new BigDecimal(otherNum).multiply(one.getOtherTaxPrice()));
                        }else {
                            one.setSettlementCenterOtherTaxMny(BigDecimal.ZERO);
                        }
                        if (one.getSettlementCenterOtherTaxMny() != null && !one.getSettlementCenterOtherTaxMny().equals(BigDecimal.ZERO)
                                && one.getOtherTaxRate() != null && !one.getOtherTaxRate().equals(BigDecimal.ZERO)
                        ){
                            //统计产值(无税)
                            one.setSettlementCenterOtherMny(one.getSettlementCenterOtherTaxMny().divide(new BigDecimal(1).add(new BigDecimal(0.01).multiply(one.getOtherTaxRate())),2, RoundingMode.HALF_DOWN));
                            //税额
                            one.setSettlementCenterOtherTax(one.getSettlementCenterOtherMny().multiply(one.getOtherTaxRate()).multiply(new BigDecimal(0.01)));

                        }else {
                            one.setSettlementCenterOtherMny(BigDecimal.ZERO);
                            one.setSettlementCenterOtherTax(BigDecimal.ZERO);
                        }
                        one.setDcDrwgrpInfo(drwgrpInfoEntity.getId());
                        if (StringUtils.isNotEmpty(memo)){
                            one.setOtherMemo(memo);
                        }
                        SettlementCenterBudgetOtherVO vo = BeanMapper.map(one, SettlementCenterBudgetOtherVO.class);
                        successList.add(vo);
                    } else {
                        SettlementCenterBudgetOtherVO vo = new SettlementCenterBudgetOtherVO();
                        logger.info("第" + i + "行数据:" + StringUtils.join(data, ","));
                        vo.setRowIndex(i);
                        vo.setErrorMessage("明细未找到");
                        errorList.add(vo);
                    }

                }
            }


        }
        JSONObject json = new JSONObject();
        json.put("successList", successList);
        rtErrorList = errorList.stream().sorted(Comparator.comparing(SettlementCenterBudgetOtherVO::getRowIndex)).collect(Collectors.toList());
        json.put("errorList", rtErrorList);
        CommonResponse<JSONObject> success = CommonResponse.success(json);
        return success;
    }
}
